@@ -19,12 +19,28 @@ GGIR = function(mode = 1:5, datadir = c(), outputdir = c(),
       for (dupi in unique(argNames[dupArgNames])) {
         dupArgValues = input[which(argNames %in% dupi)]
         if (all(dupArgValues == dupArgValues[[1]])) { # duplicated arguments, but no confusion about what value should be
-          warning(paste0("\nArgument ", dupi, " has been provided more than once. Try to avoid this."))
+          warning(paste0("\nParameter ", dupi, " has been provided more than once. Try to avoid this."))
         } else {# duplicated arguments, and confusion about what value should be,
-          warning(paste0("\nArgument ", dupi, " has been provided more than once and with inconsistent values. Please fix."))
+          warning(paste0("\nParameter ", dupi, " has been provided more than once and with inconsistent values. Please fix."))
         }
       }
     }
+    default_params = load_params()
+    known_param_names =  unlist(lapply(names(default_params), function(n) names(default_params[[n]])))
+    if (any(argNames %in% known_param_names == FALSE)) {
+      unknown_param_names = argNames[argNames %in% known_param_names == FALSE]
+      if (length(unknown_param_names) == 1) {
+        stop(paste0("\nParameter ", unknown_param_names,
+                       " is unknown to GGIR and will not be used, ",
+                    "please check for typos or remove."), call. = FALSE)
+      } else {
+        stop(paste0("\nParameters ", paste0(unknown_param_names, collapse = " and "),
+                       " are unknown to GGIR and will not be used, ",
+                    "please check for typos or remove these."), call. = FALSE)
+      }
+      rm(unknown_param_names)
+    }
+    rm(default_params, known_param_names)
   }
   
   if (length(datadir) == 0) {
@@ -183,9 +199,7 @@ GGIR = function(mode = 1:5, datadir = c(), outputdir = c(),
   if (dir.exists(outputdir) == FALSE) {
     stop("\nDirectory specified by argument outputdir does not exist")
   }
-  if (file.access(outputdir, mode = 2) == 0) {
-    if (verbose == TRUE) cat("\nChecking that user has write access permission for directory specified by argument outputdir: Yes\n")
-  } else {
+  if (file.access(outputdir, mode = 2) != 0) {
     stop("\nUser does not seem to have write access permissions for the directory specified by argument outputdir.\n")
   }
   if (filelist == TRUE) {
@@ -223,18 +237,31 @@ GGIR = function(mode = 1:5, datadir = c(), outputdir = c(),
   }
   if (verbose == TRUE) {
     cat(paste0("\n   GGIR version: ",GGIRversion,"\n"))
-    cat("\n   Do not forget to cite GGIR in your publications via a version number and\n")
-    cat("   Migueles et al. 2019 JMPB. doi: 10.1123/jmpb.2018-0063. \n")
-    cat("   See also: https://cran.r-project.org/package=GGIR/vignettes/GGIR.html#citing-ggir")
+    cat("\n   << Please cite GGIR in your publications with doi: 10.5281/zenodo.1051064 >>\n")
+    random_message = sample(x = 1:3, size = 1)
+    cat(paste0("\n   [Note #", random_message, "]"))
+    if (random_message == 1) {
+      cat("\n   To help us track where GGIR was in the literature, post a link to your publication ")
+      cat("\n   in https://github.com/wadpac/GGIR/discussions/categories/show-and-tell")
+      cat("\n   or email it to v.vanhees@accelting.com")
+    } else if (random_message == 2) {
+      cat("\n   To make your research reproducible and interpretable always report:")
+      cat("\n     (1) GGIR version")
+      cat("\n     (2) Accelerometer brand and product name")
+      cat("\n     (3) How you configured the accelerometer")
+      cat("\n     (4) Study protocol and wear instructions given to the participants")
+      cat("\n     (5) How GGIR was used: Share the config.csv file or your R script.")
+      cat("\n     (6) How you post-processed / cleaned GGIR output")
+      cat("\n     (7) How reported outcomes relate to the specific variable names in GGIR")
+    } else if (random_message == 3) {
+      cat("\n   The sustainability of GGIR depends on YOU as user, please consider:")
+      cat("\n     (1) Helping other users on https://github.com/wadpac/GGIR/discussions")
+      cat("\n     (2) Providing feedback on or help improve GGIR documentation")
+      cat("\n     (3) Providing feedback on or help improve GGIR source code")
+      cat("\n     (4) Finding funding for work on GGIR")
+      cat("\n   For questions about contributing contact v.vanhees@accelting.com.")
+    }
     cat("\n")
-    cat("\n   To make your research reproducible and interpretable always report:")
-    cat("\n     (1) Accelerometer brand and product name")
-    cat("\n     (2) How you configured the accelerometer")
-    cat("\n     (3) Study protocol and wear instructions given to the participants")
-    cat("\n     (4) GGIR version")
-    cat("\n     (5) How GGIR was used: Share the config.csv file or your R script.")
-    cat("\n     (6) How you post-processed / cleaned GGIR output")
-    cat("\n     (7) How reported outcomes relate to the specific variable names in GGIR")
   }
   #-----------------------------------------------------------
   # Now run GGIR parts 1-5
@@ -365,7 +392,7 @@ GGIR = function(mode = 1:5, datadir = c(), outputdir = c(),
                           "is_read.gt3x_installed", "is_ActCR_installed", 
                           "is_actilifecounts_installed", "rawaccfiles", "is_readxl_installed", 
                           "checkFormat", "getExt", "rawaccfiles_formats",
-                          "f1_orinally_null") == FALSE)]
+                          "f1_orinally_null", "random_message") == FALSE)]
   
   config.parameters = mget(LS)
   config.matrix = as.data.frame(createConfigFile(config.parameters, GGIRversion))
@@ -453,13 +480,12 @@ GGIR = function(mode = 1:5, datadir = c(), outputdir = c(),
       # The new visual report
       visualReport(metadatadir = metadatadir,
                    f0 = f0, f1 = f1,
-                   overwrite = params_general[["overwrite"]],
-                   desiredtz = params_general[["desiredtz"]],
-                   verbose = TRUE,
+                   verbose = verbose,
                    part6_threshold_combi = params_phyact[["part6_threshold_combi"]],
                    GGIRversion = GGIRversion,
                    params_sleep = params_sleep,
-                   params_output = params_output)
+                   params_output = params_output,
+                   params_general = params_general)
       if (params_output[["old_visualreport"]] == TRUE) {
         g.plot5(metadatadir = metadatadir,
                 dofirstpage = params_output[["dofirstpage"]],
