@@ -220,7 +220,7 @@ g.analyse =  function(I, C, M, IMP, params_247 = c(), params_phyact = c(),
                                      doiglevels = doiglevels, nfulldays = nfulldays,
                                      lastmidnight = lastmidnight,
                                      ws3 = ws3, ws2 = ws2, qcheck = qcheck, fname = fname,
-                                     idloc = idloc, sensor.location = sensor.location,
+                                     sensor.location = sensor.location,
                                      wdayname = wdayname,
                                      tooshort = tooshort, includedaycrit = includedaycrit,
                                      quantiletype = quantiletype, doilevels = doilevels, 
@@ -228,8 +228,9 @@ g.analyse =  function(I, C, M, IMP, params_247 = c(), params_phyact = c(),
                                      mvpanames = mvpanames, wdaycode = wdaycode, ID = ID, 
                                      deviceSerialNumber = deviceSerialNumber,
                                      doquan = doquan,  ExtFunColsi = ExtFunColsi,
-                                     myfun = myfun, desiredtz = desiredtz,
-                                     params_247 = params_247, params_phyact = params_phyact)
+                                     myfun = myfun,
+                                     params_247 = params_247, params_phyact = params_phyact,
+                                     params_general = params_general)
   }
   #metashort is shortened from midgnight to midnight if requested (data_masking_strategy 2)
   if (data_masking_strategy == 2) {
@@ -246,8 +247,9 @@ g.analyse =  function(I, C, M, IMP, params_247 = c(), params_phyact = c(),
   #====================================================================
   # Analysis per recording (entire file), and merge in average day analysis results
   #====================================================================
-  # Extract the average 24 hr but ignore angle metrics
-  lookattmp = which(colnames(metashort) %in% c("angle","anglex", "angley", "anglez") ==  FALSE)
+  # Extract the average 24 hr but ignore angle metrics and externally extracted sleep
+  lookattmp = which(colnames(metashort) %in% c("angle","anglex", "angley", "anglez",
+                                               "ExtSleep", "marker") ==  FALSE)
   lookat = lookattmp[which(lookattmp > 1)] #]c(2:ncol(metashort[,lookattmp]))
   colnames_to_lookat = colnames(metashort)[lookat]
   AveAccAve24hr = matrix(NA,length(lookat),1)
@@ -349,6 +351,10 @@ g.analyse =  function(I, C, M, IMP, params_247 = c(), params_phyact = c(),
       file_summary$Dur_freqissue_30 = QCsummarise(M$QClog, freqissue)
       file_summary$Nblock_freqissue_30 = length(freqissue)
     }
+    if ("filehealth_ExtSleep_y_ExtAct_missing" %in% colnames(M$QClog)) {
+      # Fitbit data
+      file_summary = cbind(file_summary, as.data.frame(M$QClog))
+    }
   }
   
   metrics_nav = list(lookat = lookat,
