@@ -46,6 +46,8 @@ g.dotorcomma = function(inputfile, dformat, mon, ...) {
                                                  start = 1, end = 3)}, silent = TRUE)
       if (!exists("deci")) stop("Problem with reading .bin file in GGIR function dotorcomma")
       if (is.na(as.numeric(deci$data.out[2, 2])) == T & decn == ".") decn = ","
+    } else if (mon == MONITOR$PARMAY_MTX) {
+      decn = "." 
     }
   } else if (dformat == FORMAT$CWA) {
     try(expr = {deci = GGIRread::readAxivity(filename = inputfile, start = 1, end = 10,
