@@ -1,5 +1,5 @@
 g.loadlog = function(loglocation = c(), coln1 = c(), colid = c(), 
-                     sleeplogsep = ",", meta.sleep.folder = c(), desiredtz="") {
+                     sleeplogsep = ",", meta.sleep.folder = c(), desiredtz="", sleepwindowType = c()) {
   # declare local functions:
   getIDstartdate = function(x) {
     rec_starttime = ID = c()
@@ -49,7 +49,7 @@ g.loadlog = function(loglocation = c(), coln1 = c(), colid = c(),
     if (ncol(x) == 1) x = NULL
     return(x)
   }
-  adjustLogFormat = function(S, nnights, mode = "sleeplog") {
+  adjustLogFormat = function(S, nnights, mode = "sleeplog", coln1) {
     # function to adjust the sleeplog or bedlog format
     log = matrix(0,(nrow(S)*nnights),3)
     log_times = matrix(" ", (nrow(S) * nnights), 2)
@@ -133,9 +133,16 @@ g.loadlog = function(loglocation = c(), coln1 = c(), colid = c(),
                         check.names = TRUE, colClasses = "character")
   # Check for duplicated ID
   if (any(duplicated(S[, colid]))) {
-    stop(paste0("Sleeplog has duplicated entries (rows) for ID(s) ",
-                paste0(S[duplicated(S[, colid]), colid], collapse = " "), 
-                ", please fix. GGIR expects one sleeplog row per unique ID. "), call. = FALSE)
+    duplicatedIDs = paste0(S[duplicated(S[, colid]), colid], collapse = " ")
+    duplicatedIDs = gsub(pattern = " ", replacement = "", x = duplicatedIDs)
+    if (duplicatedIDs != "") {
+      stop(paste0("Sleeplog has duplicated entries (rows) for ID(s) ",
+                  duplicatedIDs, 
+                  ", please fix. GGIR expects one sleeplog row per unique ID. "), call. = FALSE)
+    } else {
+      # Duplicated rows without an ID, ignore these
+      S = S[!duplicated(S[, colid]),]
+    }
   }
   
   if (colnames(S)[1] == "V1" && any(S[1, ] == "")) {
@@ -481,14 +488,20 @@ g.loadlog = function(loglocation = c(), coln1 = c(), colid = c(),
     nnights = floor(nnights)
   }
   nnights = nnights + deltadate + 1 # to account for the possibility of extra night at the beginning of recording
+  if (!is.null(sleepwindowType) && advanced_sleeplog == FALSE) {
+    if (sleepwindowType == "TimeInBed") {
+      B = S
+      rm(S)
+    }
+  }
   # # From here we continue with original code focused on sleeplog only
   if (exists("S") && ncol(S) > 0 && nnights > 0) {
-    sleeplog = adjustLogFormat(S, nnights, mode = "sleeplog")
+    sleeplog = adjustLogFormat(S, nnights, mode = "sleeplog", coln1)
   } else {
     sleeplog = NULL
   }
-  if (exists("B") && nnights > 0) {
-    bedlog = adjustLogFormat(B, nnights, mode = "bedlog")
+  if (exists("B") && ncol(B) > 0 && nnights > 0) {
+    bedlog = adjustLogFormat(B, nnights, mode = "bedlog", coln1)
   } else {
     bedlog = NULL
   }
