@@ -1,5 +1,4 @@
-g.part5.definedays = function(nightsi, wi, indjump, nightsi_bu,
-                              epochSize, qqq_backup = c(), ts, timewindowi, 
+g.part5.definedays = function(nightsi, wi, indjump, epochSize, qqq_backup = c(), ts, timewindowi, 
                               Nwindows, qwindow, ID = NULL,
                               dayborder = 0) {
   Nts = nrow(ts)
@@ -51,7 +50,12 @@ g.part5.definedays = function(nightsi, wi, indjump, nightsi_bu,
     }
     # define window
     qqq[1] = nightsi[wi]
-    qqq[2] = nightsi[wi + 1] - 1
+    if (length(nightsi) >= wi + 1) {
+      qqq[2] = nightsi[wi + 1] - 1
+    } else {
+      qqq[2] = Nts
+      lastDay = TRUE
+    }
     # is this the last day?
     if (wi == length(nightsi) - 1) {
       lastDay = TRUE
@@ -75,6 +79,9 @@ g.part5.definedays = function(nightsi, wi, indjump, nightsi_bu,
         if (length(qdate) == 1) { # if ID/date matched with activity log
           qnames = unlist(qwindow$qwindow_names[qdate])
           qwindow = unlist(qwindow$qwindow_values[qdate])
+          qwindow_order = order(qwindow)
+          qwindow = qwindow[qwindow_order]
+          qnames = qnames[qwindow_order]
         } else { # if ID/date not correctly matched with activity log
           qwindow = c(0, 24)
         }
