@@ -15,7 +15,6 @@ g.sib.det = function(M, IMP, I, twd = c(-12, 12),
     params_sleep = params$params_sleep
   }
   #==============================================================
-  perc = 10; spt_threshold = 15; sptblocksize = 30; spt_max_gap = 60 # default configurations (keep hardcoded for now
   # Abbreviaton SPTE = Sleep Period Time Estimate, although in case of HorAngle it is the Time in Bed estimate
   # but then we would have to come up with yet another term to represent the main sleep and/or time in bed window of the day
   # So, out of convenience I keep the object name SPTE. 
@@ -103,7 +102,7 @@ g.sib.det = function(M, IMP, I, twd = c(-12, 12),
       }
     }
     ACC = as.numeric(as.matrix(IMP$metashort[,which(colnames(IMP$metashort) == acc.metric)]))
-    night = rep(0, length(ACC))
+    night = spt_crude_estimate = rep(0, length(ACC))
     
     if ("marker" %in% colnames(IMP$metashort)) {
       MARKER = as.numeric(as.matrix(IMP$metashort[,which(colnames(IMP$metashort) == "marker")]))
@@ -248,7 +247,7 @@ g.sib.det = function(M, IMP, I, twd = c(-12, 12),
           qqq2 = midnightsi[j] + (twd[2] * (3600 / ws3)) #next noon
         }
         # twd assumed 24 hour window, which is not the case for DST
-        if (qqq2 < length(time)) {
+        if (qqq2 < length(time) & qqq2 > 0) {
           qqq2_hour = as.numeric(format(iso8601chartime2POSIX(time[qqq2], tz = desiredtz), "%H"))
           if (qqq2_hour == 11) {
             qqq2 = qqq2 + (3600 / ws3)
@@ -265,17 +264,18 @@ g.sib.det = function(M, IMP, I, twd = c(-12, 12),
         } else {
           partialFirstDay = FALSE
         }
-        night[qqq1:qqq2] = sptei
+        tSegment = qqq1:qqq2
+        night[tSegment] = sptei
         detection.failed = FALSE
         # Calculate nonwear percentage for this window
-        nonwear_percentage = (length(which(invalid[qqq1:qqq2] == 1)) /  (qqq2 - qqq1 + 1)) * 100
+        nonwear_percentage = (length(which(invalid[tSegment] == 1)) /  (qqq2 - qqq1 + 1)) * 100
         guider_to_use = decide_guider(params_sleep[["HASPT.algo"]], nonwear_percentage)
         #------------------------------------------------------------------
         # calculate L5 because this is used as back-up approach
-        tmpACC = ACC[qqq1:qqq2]
+        tmpACC = ACC[tSegment]
         windowRL = round((3600/ws3) * 5)
         if ((windowRL / 2) == round(windowRL / 2)) windowRL = windowRL + 1
-        if (length(tmpACC) < windowRL) {  0 # added 4/4/2-17
+        if (length(tmpACC) <= windowRL) {
           L5 = 0
         } else {
           ZRM = zoo::rollmean(x = tmpACC, k = windowRL, fill = "extend", align = "center")
@@ -289,27 +289,26 @@ g.sib.det = function(M, IMP, I, twd = c(-12, 12),
         }
         L5list[sptei] = L5
         # Estimate Sleep Period Time window, because this will be used by g.part4 if sleeplog is not available
-        tmpANGLE = anglez[qqq1:qqq2]
-        tmpTIME = time[qqq1:qqq2]
+        tmpANGLE = anglez[tSegment]
+        tmpTIME = time[tSegment]
         daysleep_offset = 0
         if (do.HASPT.hip == TRUE & params_sleep[["HASPT.algo"]][guider_to_use] != "NotWorn") {
           if (params_sleep[["longitudinal_axis"]] == 1) {
-            tmpANGLE = anglex[qqq1:qqq2]
+            tmpANGLE = anglex[tSegment]
           } else if (params_sleep[["longitudinal_axis"]] == 2) {
-            tmpANGLE = angley[qqq1:qqq2]
+            tmpANGLE = angley[tSegment]
           }
         }
         if (length(params_sleep[["def.noc.sleep"]]) == 1) {
+          
           spt_estimate = HASPT(angle = tmpANGLE, ws3 = ws3,
-                               sptblocksize = sptblocksize, spt_max_gap = spt_max_gap,
+                               params_sleep = params_sleep,
                                HASPT.algo = params_sleep[["HASPT.algo"]][guider_to_use],
-                               invalid = invalid[qqq1:qqq2], # load only invalid time in the night of interest (i.e., qqq1:qqq2)
-                               HDCZA_threshold = params_sleep[["HDCZA_threshold"]],
-                               HASPT.ignore.invalid = params_sleep[["HASPT.ignore.invalid"]],
+                               invalid = invalid[tSegment],
                                activity = tmpACC,
-                               marker = MARKER[qqq1:qqq2],
-                               sibs = sleep[qqq1:qqq2, 1],
-                               try_marker_button = params_sleep[["consider_marker_button"]])
+                               marker = MARKER[tSegment],
+                               sibs = sleep[tSegment, 1])
+          tSegment_backup = tSegment
         } else {
           spt_estimate = list(SPTE_end = NULL, SPTE_start = NULL, tib.threshold = NULL, part3_guider = NULL)
         }
@@ -327,31 +326,29 @@ g.sib.det = function(M, IMP, I, twd = c(-12, 12),
             if (newqqq2 > length(anglez)) newqqq2 = length(anglez)
             # only try to extract SPT again if it is possible to extract a window of more than 23 hour
             if (newqqq2 < length(anglez) & (newqqq2 - newqqq1) > (23 * (3600/ws3)) ) {
+              tSegment = newqqq1:newqqq2
               # Recalculate nonwear percentage for new window (6pm to 6pm)
-              nonwear_percentage = (length(which(invalid[newqqq1:newqqq2] == 1)) /  (newqqq2 - newqqq1 + 1)) * 100
+              nonwear_percentage = (length(which(invalid[tSegment] == 1)) /  (newqqq2 - newqqq1 + 1)) * 100
               guider_to_use = decide_guider(params_sleep[["HASPT.algo"]], nonwear_percentage)
               # new TIME (6pm tp 6pm)
-              tmpTIME = time[newqqq1:newqqq2]
+              tmpTIME = time[tSegment]
               if (params_sleep[["HASPT.algo"]][guider_to_use] != "NotWorn") {
-                tmpANGLE = anglez[newqqq1:newqqq2]
+                tmpANGLE = anglez[tSegment]
                 if (do.HASPT.hip == TRUE) {
                   if (params_sleep[["longitudinal_axis"]] == 1) {
-                    tmpANGLE = anglex[newqqq1:newqqq2]
+                    tmpANGLE = anglex[tSegment]
                   } else if (params_sleep[["longitudinal_axis"]] == 2) {
-                    tmpANGLE = angley[newqqq1:newqqq2]
+                    tmpANGLE = angley[tSegment]
                   }
                 }
               }
               spt_estimate_tmp = HASPT(angle = tmpANGLE, ws3 = ws3,
-                                       sptblocksize = sptblocksize, spt_max_gap = spt_max_gap,
+                                       params_sleep = params_sleep,
                                        HASPT.algo = params_sleep[["HASPT.algo"]][guider_to_use],
-                                       invalid = invalid[newqqq1:newqqq2],
-                                       HDCZA_threshold = params_sleep[["HDCZA_threshold"]],
-                                       HASPT.ignore.invalid = params_sleep[["HASPT.ignore.invalid"]],
-                                       activity = ACC[newqqq1:newqqq2],
-                                       marker = MARKER[newqqq1:newqqq2],
-                                       sibs = sleep[newqqq1:newqqq2, 1],
-                                       try_marker_button = params_sleep[["consider_marker_button"]])
+                                       invalid = invalid[tSegment],
+                                       activity = ACC[tSegment],
+                                       sibs = sleep[tSegment, 1])
+             
               if (length(spt_estimate_tmp$SPTE_start) > 0) {
                 # If new SPTE_end is beyond noon (qqq2) then use the new SPTE_end
                 if (spt_estimate_tmp$SPTE_end + newqqq1 >= qqq2) {
@@ -385,6 +382,16 @@ g.sib.det = function(M, IMP, I, twd = c(-12, 12),
           tib.threshold[sptei] = spt_estimate$tib.threshold
           part3_guider[sptei] = spt_estimate$part3_guider
         }
+        # log crude estimate as well:
+        if (length(spt_estimate$spt_crude_estimate) == length(tSegment)) {
+          spt_crude_estimate[tSegment] = spt_estimate$spt_crude_estimate
+        } else if (length(spt_estimate$spt_crude_estimate) == length(tSegment_backup)) {
+          spt_crude_estimate[tSegment_backup] = spt_estimate$spt_crude_estimate
+        } else {
+          if (!is.null(spt_estimate$spt_crude_estimate)) {
+            warning("Crude estimate of sleep has unexpected length, please contact GGIR maintainer.")
+          }
+        }
       }
       detection.failed = FALSE
     } else {
@@ -392,8 +399,11 @@ g.sib.det = function(M, IMP, I, twd = c(-12, 12),
       detection.failed = TRUE
     }
     metatmp = data.frame(time, invalid, night = night, sleep = sleep, stringsAsFactors = T)
+    if (!is.null(spt_crude_estimate)) {
+      metatmp$spt_crude_estimate = spt_crude_estimate
+    }
   } else {
-    metatmp = L5list = SPTE_end = SPTE_start = tib.threshold = part3_guider = c()
+    metatmp = L5list = SPTE_end = SPTE_start = tib.threshold = part3_guider = NULL
     detection.failed = TRUE
   }
   invisible(list(output = metatmp, detection.failed = detection.failed, L5list = L5list,
