@@ -267,17 +267,12 @@ read.myacc.csv = function(rmc.file=c(), rmc.nrow=Inf, rmc.skip=c(), rmc.dec=".",
       }
     } else if (rmc.unit.time == "ActivPAL") {
       # origin should be specified as: "1899-12-30"
-      rmc.origin = "1899-12-30"
-      datecode = round(P$time) * 3600*24
-      tmp2 = P$time - round(P$time)
-      timecode = ((tmp2 * 10^10) * 8.64) / 1000000
-      numerictime = datecode + timecode
-      P$time = as.POSIXct(numerictime, origin = rmc.origin, tz = desiredtz)
+      P$time = lubridate::force_tz(as.POSIXct(P$time * 86400, origin = "1899-12-30", tz = "UTC"), tz = desiredtz)
     }
     if (length(which(is.na(P$time) == FALSE)) == 0) {
       stop("\nExtraction of timestamps unsuccesful, check timestamp format arguments")
     }
-    if(!is.numeric(P$time)) { # we'll return Unix timestamps
+    if (!is.numeric(P$time)) { # we'll return Unix timestamps
       P$time = as.numeric(P$time)
     }
   }
