@@ -206,7 +206,7 @@ test_that("chainof5parts", {
           loglocation = sleeplog_fn,
           overwrite = TRUE, excludefirstlast = FALSE, do.parallel = do.parallel,
           frag.metrics = "all", save_ms5rawlevels = TRUE, save_ms5raw_format = "csv",
-          part5_agg2_60seconds = TRUE, do.sibreport = TRUE, nap_model = "hip3yr",
+          part5_agg2_60seconds = TRUE, do.sibreport = TRUE, 
           iglevels = 1, timewindow = c("MM", "WW", "OO"),
           possible_nap_window = c(0, 24),
           possible_nap_dur = c(0, 240),
@@ -225,7 +225,7 @@ test_that("chainof5parts", {
   expect_true(dir.exists(dirname))
   expect_true(file.exists(rn[1]))
   expect_that(nrow(output),equals(5))
-  expect_that(ncol(output),equals(160))
+  expect_that(ncol(output),equals(158))
   expect_that(round(as.numeric(output$wakeup[2]), digits = 4), equals(36))
   expect_that(as.numeric(output$dur_day_spt_min[4]), equals(1150)) # WW window duration
   expect_that(as.numeric(output$dur_day_spt_min[5]), equals(1680)) # OO window duration
@@ -235,7 +235,7 @@ test_that("chainof5parts", {
   expect_true(file.exists(rn2[rn2_index]))
   TSFILE = read.csv(rn2[rn2_index])
   expect_that(nrow(TSFILE),equals(2820))
-  expect_equal(ncol(TSFILE), 14)
+  expect_equal(ncol(TSFILE), 13)
   expect_equal(length(unique(TSFILE$class_id)), 11)
   #GGIR
   suppressWarnings(GGIR(mode = c(2,3,4,5), datadir = fn, outputdir = getwd(),
@@ -247,7 +247,7 @@ test_that("chainof5parts", {
                         f0 = 1, f1 = 1,
                         do.report = c(), overwrite = FALSE, visualreport = TRUE, viewingwindow = 1,
                         do.parallel = do.parallel, minimumFileSizeMB = minimumFileSizeMB, 
-                        verbose = FALSE))
+                        verbose = FALSE, old_visualreport = TRUE))
   expect_true(file.exists("output_test/results/part2_daysummary.csv"))
   expect_true(file.exists("output_test/results/part2_summary.csv"))
   expect_true(file.exists("output_test/results/part4_nightsummary_sleep_cleaned.csv"))
@@ -258,6 +258,26 @@ test_that("chainof5parts", {
   expect_true(file.exists("output_test/results/part5_daysummary_OO_L40M100V400_T5A5.csv"))
   dn = "output_test"
   
+  # Expect warning when unknown parameters are provided
+  expect_error(GGIR(mode = NULL, datadir = fn, outputdir = getwd(),
+                    studyname = "test", f0 = 1, f1 = 1,
+                    do.report = NULL, overwrite = FALSE,
+                    verbose = FALSE,
+                    iamnewhere = 0),
+               paste0("\nParameter iamnewhere is unknown to GGIR and will not be",
+                      " used, please check for typos or remove."))
+  
+  expect_error(GGIR(mode = NULL, datadir = fn, outputdir = getwd(),
+                    studyname = "test", f0 = 1, f1 = 1,
+                    do.report = NULL, overwrite = FALSE,
+                    verbose = FALSE,
+                    iamnewhere = 0,
+                    iamnewtoo = 1),
+               paste0("\nParameters iamnewhere and iamnewtoo are unknown",
+                      " to GGIR and will not be used, please check for ",
+                      "typos or remove these."))
+  
+
   #=======================
   # Different variations on part 4:
   #--------------------------------------------
