@@ -5,5 +5,5 @@ test_that("g.impute returns a non-empty dataframe", {
   data(data.inspectfile)
   data(data.calibrate)
   IMP = g.impute(M = data.getmeta, I = data.inspectfile)
-  expect_equal(length(IMP),12)  # 12 because now it also stores r5long to ease ignoring the expanded time (if not expanded, then it is not used)
+  expect_equal(length(IMP), 14)
 })
\ No newline at end of file
