@@ -21,8 +21,7 @@ test_that("g.weardec relabels data correctly", {
   # No non-wear, no clipping
   metalong = data.frame(nonwearscore = createNW(),
                         clippingscore = rep(0, Ntotal))
-  M = list(metalong = metalong)
-  out = g.weardec(M, wearthreshold, ws2, params_cleaning = params_cleaning)
+  out = g.weardec(metalong = metalong, wearthreshold, ws2, params_cleaning = params_cleaning)
   expect_equal(sum(out$r1), 0)
   expect_equal(sum(out$r2), 0)
   expect_equal(sum(out$r3), 0)
@@ -32,8 +31,7 @@ test_that("g.weardec relabels data correctly", {
   # Non-wear a few epoch in the first 3 hours, no clipping
   metalong = data.frame(nonwearscore = c(rep(0, 3), rep(3, 2), rep(0, Ntotal - 5)),
                         clippingscore = rep(0, Ntotal))
-  M = list(metalong = metalong)
-  out = g.weardec(M, wearthreshold, ws2, params_cleaning = params_cleaning)
+  out = g.weardec(metalong, wearthreshold, ws2, params_cleaning = params_cleaning)
   expect_equal(sum(out$r1), 2)
   expect_equal(sum(out$r3), 3)
   expect_equal(sum(out$r1 + out$r3), 5)
@@ -41,8 +39,7 @@ test_that("g.weardec relabels data correctly", {
   # Non-wear a few epoch in the last 3 hours, no clipping
   metalong = data.frame(nonwearscore = c(rep(0, Ntotal - 5), rep(3, 2), rep(0, 3)),
                         clippingscore = rep(0, Ntotal))
-  M = list(metalong = metalong)
-  out = g.weardec(M, wearthreshold, ws2, params_cleaning = params_cleaning)
+  out = g.weardec(metalong, wearthreshold, ws2, params_cleaning = params_cleaning)
   expect_equal(sum(out$r1), 2)
   expect_equal(sum(out$r3), 3)
   expect_equal(sum(out$r1 + out$r3), 5)
@@ -50,8 +47,7 @@ test_that("g.weardec relabels data correctly", {
   # Non-wear 20 in middle + clipping
   metalong = data.frame(nonwearscore = createNW(Nnonwear = 20),
                         clippingscore = c(rep(0, Ntotal - 100), rep(1, 100)))
-  M = list(metalong = metalong)
-  out = g.weardec(M, wearthreshold, ws2, params_cleaning = params_cleaning)
+  out = g.weardec(metalong, wearthreshold, ws2, params_cleaning = params_cleaning)
   expect_equal(sum(out$r1), 20)
   expect_equal(sum(out$r2), 100)
   expect_equal(sum(out$r3), 0)
@@ -59,8 +55,7 @@ test_that("g.weardec relabels data correctly", {
   # Wear 20 in the middle + clipping
   metalong = data.frame(nonwearscore = createNW(Nnonwear = 20, invert = TRUE),
                         clippingscore = c(rep(0, Ntotal - 200), rep(1, 200)))
-  M = list(metalong = metalong)
-  out = g.weardec(M, wearthreshold, ws2, params_cleaning = params_cleaning)
+  out = g.weardec(metalong, wearthreshold, ws2, params_cleaning = params_cleaning)
   expect_equal(sum(out$r1), 280)
   expect_equal(sum(out$r2), 200)
   expect_equal(sum(out$r3), 20)
@@ -69,8 +64,7 @@ test_that("g.weardec relabels data correctly", {
   # Non-wear 100 in middle + clipping
   metalong = data.frame(nonwearscore = createNW(Nnonwear = 100),
                         clippingscore = c(rep(0, Ntotal - 15), rep(1, 15)))
-  M = list(metalong = metalong)
-  out = g.weardec(M, wearthreshold, ws2, params_cleaning = params_cleaning)
+  out = g.weardec(metalong, wearthreshold, ws2, params_cleaning = params_cleaning)
   expect_equal(sum(out$r1), 100)
   expect_equal(sum(out$r2), 15)
   expect_equal(sum(out$r3), 0)
@@ -78,8 +72,7 @@ test_that("g.weardec relabels data correctly", {
   # Wear 100 in the middle + clipping
   metalong = data.frame(nonwearscore = createNW(Nnonwear = 100, invert = TRUE),
                         clippingscore = c(rep(0, Ntotal - 280), rep(1, 280)))
-  M = list(metalong = metalong)
-  out = g.weardec(M, wearthreshold, ws2, params_cleaning = params_cleaning)
+    out = g.weardec(metalong, wearthreshold, ws2, params_cleaning = params_cleaning)
   expect_equal(sum(out$r1), 200)
   expect_equal(sum(out$r2), 280)
   expect_equal(sum(out$r3), 0)
@@ -94,8 +87,7 @@ test_that("g.weardec relabels data correctly", {
   timestamp = POSIXtime2iso8601(seq(as.POSIXct("2024-10-29 00:00:00", tz = tz),
                                     by = ws2, length.out = nrow(metalong)), tz = tz)
   metalong$timestamp = timestamp
-  M = list(metalong = metalong)
-  out = g.weardec(M, wearthreshold, ws2, params_cleaning = params_cleaning)
+  out = g.weardec(metalong, wearthreshold, ws2, params_cleaning = params_cleaning)
   expect_equal(sum(out$r1), 60)
   expect_equal(sum(out$r2), 280)
   expect_equal(sum(out$r3), 48)
